@@ -98,9 +98,6 @@ struct _GrlRegistryPrivate {
 
 static void grl_registry_setup_ranks (GrlRegistry *registry);
 
-static void grl_registry_preload_plugins (GrlRegistry *registry,
-                                          GList **plugins_loaded);
-
 static void key_id_handler_init (struct KeyIDHandler *handler);
 
 static void key_id_handler_free (struct KeyIDHandler *handler);
@@ -450,56 +447,6 @@ compare_by_rank (gconstpointer a,
   return (rank_a < rank_b) - (rank_a > rank_b);
 }
 
-static GHashTable *
-get_info_from_plugin_xml (const gchar *xml_path)
-{
-  GHashTable *hash_table;
-  xmlNodePtr node, info_node, child;
-  xmlDocPtr doc_ptr = xmlReadFile (xml_path,
-				   NULL,
-				   XML_PARSE_RECOVER | XML_PARSE_NOBLANKS |
-				   XML_PARSE_NOWARNING | XML_PARSE_NOERROR);
-  if (!doc_ptr) {
-    GRL_MESSAGE ("Could not read XML file under the location: %s", xml_path);
-    return NULL;
-  }
-
-  node = xmlDocGetRootElement (doc_ptr);
-  if (!node || g_strcmp0 ((gchar *) node->name, XML_ROOT_ELEMENT_NAME)) {
-    GRL_WARNING ("%s did not have a %s root element.",
-                 xml_path,
-                 XML_ROOT_ELEMENT_NAME);
-    xmlFreeDoc (doc_ptr);
-    return NULL;
-  }
-
-  /* Get the info node */
-  info_node = node->children;
-  while (info_node) {
-    if (g_strcmp0 ((gchar *) info_node->name, "info") == 0) {
-      break;
-    }
-    info_node = info_node->next;
-  }
-  if (!info_node) {
-    xmlFreeDoc (doc_ptr);
-    return NULL;
-  }
-
-  /* Populate the hash table with the XML's info*/
-  hash_table = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
-  child = info_node->children;
-  while (child) {
-    g_hash_table_insert (hash_table,
-			 g_strdup ((gchar *) child->name),
-			 (gchar *) xmlNodeGetContent (child));
-    child = child->next;
-  }
-  xmlFreeDoc (doc_ptr);
-
-  return hash_table;
-}
-
 static gboolean
 register_keys_plugin (GrlRegistry *registry,
                       GrlPlugin *plugin,
@@ -550,165 +497,15 @@ activate_plugin (GrlRegistry *registry,
   return TRUE;
 }
 
-static GrlPlugin *
-grl_registry_preload_plugin (GrlRegistry *registry,
-                             const gchar *dirname,
-                             const gchar *plugin_info_filename)
-{
-  GHashTable *info;
-  GrlPlugin *plugin = NULL;
-  gchar *file;
-  gchar *suffix;
-  gchar *id;
-  const gchar *module_name;
-  gchar *module_filename;
-  gchar *module_fullpathname;
-
-  if ((suffix = g_strrstr (plugin_info_filename, "." GRL_PLUGIN_INFO_SUFFIX)) == NULL) {
-    return NULL;
-  }
-
-  id = g_strndup (plugin_info_filename, suffix - plugin_info_filename);
-  /* Check if plugin is already preloaded */
-  if (g_hash_table_lookup (registry->priv->plugins, id)) {
-    GRL_DEBUG ("Plugin '%s' already preloaded; skipping", id);
-    g_free (id);
-    return NULL;
-  }
-
-  /* Check if plugin is allowed */
-  if (registry->priv->allowed_plugins &&
-      !g_slist_find_custom (registry->priv->allowed_plugins,
-                            id,
-                            (GCompareFunc) g_strcmp0)) {
-    GRL_DEBUG ("Plugin '%s' not allowed; skipping", id);
-    g_free (id);
-    return NULL;
-  }
-
-  file = g_build_filename (dirname, plugin_info_filename, NULL);
-  info = get_info_from_plugin_xml (file);
-  g_free (file);
-
-  if (info) {
-    plugin = g_object_new (GRL_TYPE_PLUGIN, NULL);
-    grl_plugin_set_id (plugin, id);
-    grl_plugin_set_optional_info (plugin, info);
-    module_name = grl_plugin_get_info (plugin, GRL_PLUGIN_INFO_MODULE);
-    if (!module_name) {
-      GRL_WARNING ("Unknown module file for plugin with id '%s'", id);
-      g_object_unref (plugin);
-      g_free (id);
-      return NULL;
-    }
-
-    if (g_path_is_absolute (module_name)) {
-      grl_plugin_set_filename (plugin, module_name);
-    } else {
-      if (g_str_has_suffix (module_name, "." G_MODULE_SUFFIX)) {
-        module_fullpathname = g_build_filename (dirname, module_name, NULL);
-      } else {
-        module_filename = g_strconcat (module_name, "." G_MODULE_SUFFIX, NULL);
-        module_fullpathname = g_build_filename (dirname, module_filename, NULL);
-        g_free (module_filename);
-      }
-      grl_plugin_set_filename (plugin, module_fullpathname);
-      g_free (module_fullpathname);
-    }
-
-    g_hash_table_insert (registry->priv->plugins,
-                         id,
-                         plugin);
-  }
-  return plugin;
-}
-
-static void
-grl_registry_preload_plugins_directory (GrlRegistry *registry,
-                                        const gchar *directory,
-                                        GList **plugins_loaded)
-{
-  GDir *dir;
-  GError *error = NULL;
-  const gchar *entry;
-  GrlPlugin *plugin;
-
-  dir = g_dir_open (directory, 0, &error);
-  if (!dir) {
-    GRL_WARNING ("Could not open plugins' info directory '%s': %s",
-                 directory,
-                 error->message);
-    g_error_free (error);
-    return;
-  }
-
-  while ((entry = g_dir_read_name (dir)) != NULL) {
-    plugin = grl_registry_preload_plugin (registry, directory, entry);
-    if (plugins_loaded && plugin) {
-      *plugins_loaded = g_list_prepend (*plugins_loaded, plugin);
-    }
-  }
-
-  g_dir_close (dir);
-}
-
-static void
-grl_registry_preload_plugins (GrlRegistry *registry,
-                              GList **plugins_loaded)
-{
-  GSList *plugin_dir;
-  GList *plugins_directory_loaded = NULL;
-
-  for (plugin_dir = registry->priv->plugins_dir;
-       plugin_dir;
-       plugin_dir = g_slist_next (plugin_dir)) {
-    if (plugins_loaded) {
-      grl_registry_preload_plugins_directory (registry,
-                                              plugin_dir->data,
-                                              &plugins_directory_loaded);
-      *plugins_loaded = g_list_concat (*plugins_loaded, plugins_directory_loaded);
-      plugins_directory_loaded = NULL;
-    } else {
-      grl_registry_preload_plugins_directory (registry,
-                                              plugin_dir->data,
-                                              NULL);
-    }
-  }
-}
-
-static gboolean
-grl_registry_load_plugin_list (GrlRegistry *registry,
-                               GList *plugin_list)
-{
-  GList *l;
-  gboolean loaded_one = FALSE;
-
-  for (l = plugin_list; l ; l = l->next) {
-    GrlPlugin *plugin = l->data;
-    if (grl_plugin_get_module (plugin)) {
-      loaded_one |= register_keys_plugin (registry, plugin, NULL);
-    } else {
-      loaded_one |= (grl_registry_prepare_plugin (registry,
-                                                  grl_plugin_get_filename (plugin),
-                                                  NULL) != NULL);
-      loaded_one |= register_keys_plugin (registry, plugin, NULL);
-    }
-  }
-
-  for (l = plugin_list; l ; l = l->next) {
-    GrlPlugin *plugin = l->data;
-    loaded_one |= activate_plugin (registry, plugin, NULL);
-  }
-
-  return loaded_one;
-}
-
 static GrlKeyID
 grl_registry_register_metadata_key_full (GrlRegistry *registry,
                                          GParamSpec *param_spec,
                                          GrlKeyID key,
+                                         GrlKeyID bind_key,
                                          GError **error)
 {
+  GList *bound_partners;
+  GList *partner;
   const gchar *key_name;
 
   g_return_val_if_fail (GRL_IS_REGISTRY (registry), 0);
@@ -753,11 +550,24 @@ grl_registry_register_metadata_key_full (GrlRegistry *registry,
                        (gpointer) key_name,
                        param_spec);
 
-  /* Each key is related to itself */
-  g_hash_table_insert (registry->priv->related_keys,
-                       GRLKEYID_TO_POINTER (registered_key),
-                       g_list_prepend (NULL,
-                                       GRLKEYID_TO_POINTER (registered_key)));
+  if (bind_key == GRL_METADATA_KEY_INVALID) {
+  /* Key is only related to itself */
+    g_hash_table_insert (registry->priv->related_keys,
+                         GRLKEYID_TO_POINTER (registered_key),
+                         g_list_prepend (NULL,
+                                         GRLKEYID_TO_POINTER (registered_key)));
+  } else {
+    /* Add the new key to the partners */
+    bound_partners = g_hash_table_lookup (registry->priv->related_keys, GRLKEYID_TO_POINTER (bind_key));
+    bound_partners = g_list_append (bound_partners, GRLKEYID_TO_POINTER (registered_key));
+    for (partner = bound_partners;
+         partner;
+         partner = g_list_next (partner)) {
+      g_hash_table_insert (registry->priv->related_keys,
+                           partner->data,
+                           bound_partners);
+    }
+  }
 
   return registered_key;
 }
@@ -1207,22 +1017,22 @@ grl_registry_prepare_plugin_from_desc (GrlRegistry *registry,
 {
   GrlPlugin *plugin;
 
-  if (!plugin_desc->plugin_init ||
-      !plugin_desc->plugin_id) {
+  if (!plugin_desc->init ||
+      !plugin_desc->id) {
     GRL_WARNING ("Plugin descriptor is not valid");
     return NULL;
   }
 
   plugin = g_object_new (GRL_TYPE_PLUGIN, NULL);
-  grl_plugin_set_id (plugin, plugin_desc->plugin_id);
-  grl_plugin_set_filename (plugin, plugin_desc->plugin_id);
+  grl_plugin_set_id (plugin, plugin_desc->id);
+  grl_plugin_set_filename (plugin, plugin_desc->id);
 
-  grl_plugin_set_load_func (plugin, plugin_desc->plugin_init);
-  grl_plugin_set_unload_func (plugin, plugin_desc->plugin_deinit);
-  grl_plugin_set_register_keys_func (plugin, plugin_desc->plugin_register_keys);
+  grl_plugin_set_load_func (plugin, plugin_desc->init);
+  grl_plugin_set_unload_func (plugin, plugin_desc->deinit);
+  grl_plugin_set_register_keys_func (plugin, plugin_desc->register_keys);
 
   /* Insert plugin ID as part of plugin information */
-  grl_plugin_set_info (plugin, GRL_PLUGIN_INFO_MODULE, plugin_desc->plugin_id);
+  grl_plugin_set_module_name (plugin, plugin_desc->id);
 
   return plugin;
 }
@@ -1235,9 +1045,6 @@ grl_registry_prepare_plugin (GrlRegistry *registry,
   GModule *module;
   GrlPluginDescriptor *plugin_desc;
   GrlPlugin *plugin;
-  gchar *module_name;
-  gchar *info_dirname;
-  gchar *info_filename;
 
   g_return_val_if_fail (GRL_IS_REGISTRY (registry), FALSE);
 
@@ -1261,8 +1068,8 @@ grl_registry_prepare_plugin (GrlRegistry *registry,
     return NULL;
   }
 
-  if (!plugin_desc->plugin_init ||
-      !plugin_desc->plugin_id) {
+  if (!plugin_desc->init ||
+      !plugin_desc->id) {
     GRL_WARNING ("Plugin descriptor is not valid: '%s'", library_filename);
     g_set_error (error,
                  GRL_CORE_ERROR,
@@ -1274,25 +1081,14 @@ grl_registry_prepare_plugin (GrlRegistry *registry,
 
   /* Check if plugin is preloaded; if not, then create one */
   plugin = g_hash_table_lookup (registry->priv->plugins,
-                                plugin_desc->plugin_id);
+                                plugin_desc->id);
 
-  if (!plugin) {
-    info_dirname = g_path_get_dirname (library_filename);
-    info_filename = g_strconcat (plugin_desc->plugin_id, "." GRL_PLUGIN_INFO_SUFFIX, NULL);
-    plugin = grl_registry_preload_plugin (registry, info_dirname, info_filename);
-    g_free (info_dirname);
-    g_free (info_filename);
-    if (!plugin) {
-      g_set_error (error,
-                   GRL_CORE_ERROR,
-                   GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
-                   _("Unable to load plugin '%s'"), plugin_desc->plugin_id);
-      g_module_close (module);
-      return NULL;
-    }
-  } else {
-    /* Check if the existent plugin is for a different module */
-    if (g_strcmp0 (grl_plugin_get_filename (plugin), library_filename) != 0) {
+  if (plugin) {
+    g_module_close (module);
+    /* Check if the existent plugin is precisely this same plugin */
+    if (g_strcmp0 (grl_plugin_get_filename (plugin), library_filename) == 0) {
+      return plugin;
+    } else {
       GRL_WARNING ("Plugin '%s' already exists", library_filename);
       g_set_error (error,
                    GRL_CORE_ERROR,
@@ -1302,25 +1098,61 @@ grl_registry_prepare_plugin (GrlRegistry *registry,
     }
   }
 
-  if (!grl_plugin_get_module (plugin)) {
-    grl_plugin_set_load_func (plugin, plugin_desc->plugin_init);
-    grl_plugin_set_unload_func (plugin, plugin_desc->plugin_deinit);
-    grl_plugin_set_register_keys_func (plugin, plugin_desc->plugin_register_keys);
-
-    /* Insert module name as part of plugin information */
-    module_name = g_path_get_basename (library_filename);
-    grl_plugin_set_info (plugin, GRL_PLUGIN_INFO_MODULE, module_name);
-    g_free (module_name);
-
-    grl_plugin_set_module (plugin, module);
-
-    /* Make plugin resident */
-    g_module_make_resident (module);
+  /* Check if plugin is allowed */
+  if (registry->priv->allowed_plugins &&
+      !g_slist_find_custom (registry->priv->allowed_plugins,
+                            plugin_desc->id,
+                            (GCompareFunc) g_strcmp0)) {
+    GRL_DEBUG ("Plugin '%s' not allowed; skipping", plugin_desc->id);
+    g_module_close (module);
+    return NULL;
   }
 
+  plugin = g_object_new (GRL_TYPE_PLUGIN, NULL);
+  grl_plugin_set_desc (plugin, plugin_desc);
+  grl_plugin_set_module (plugin, module);
+  grl_plugin_set_filename (plugin, library_filename);
+
+  /* Make plugin resident */
+  g_module_make_resident (module);
+
+  g_hash_table_insert (registry->priv->plugins, g_strdup (plugin_desc->id), plugin);
+
+  /* Register custom keys */
+  grl_plugin_register_keys (plugin);
+
   return plugin;
 }
 
+/**
+ * grl_registry_activate_all_plugins:
+ * @registry: the registry instace
+ *
+ * Activate all the plugins loaded.
+ *
+ * Returns: %TRUE if some plugin has been activated
+ *
+ * Since: 0.3.0
+ **/
+gboolean
+grl_registry_activate_all_plugins (GrlRegistry *registry)
+{
+  GList *all_plugins;
+  GList *l;
+  gboolean plugin_activated = FALSE;
+
+  g_return_val_if_fail (GRL_IS_REGISTRY (registry), FALSE);
+
+  all_plugins = g_hash_table_get_values (registry->priv->plugins);
+  for (l = all_plugins; l; l = l->next) {
+    GrlPlugin *plugin = l->data;
+    plugin_activated |= activate_plugin (registry, plugin, NULL);
+  }
+  g_list_free (all_plugins);
+
+  return plugin_activated;
+}
+
 /**
  * grl_registry_load_plugin:
  * @registry: the registry instance
@@ -1344,8 +1176,7 @@ grl_registry_load_plugin (GrlRegistry *registry,
   if (!plugin)
     return FALSE;
 
-  return register_keys_plugin (registry, plugin, error) &&
-         activate_plugin (registry, plugin, error);
+  return register_keys_plugin (registry, plugin, error);
 }
 
 /**
@@ -1372,7 +1203,7 @@ grl_registry_load_plugin (GrlRegistry *registry,
  *
  * Returns: %TRUE if the plugin is initialised correctly
  *
- * Since: 0.2.15
+ * Since: 0.3.0
  */
 gboolean
 grl_registry_load_plugin_from_desc (GrlRegistry *registry,
@@ -1407,25 +1238,48 @@ grl_registry_load_plugin_directory (GrlRegistry *registry,
                                     const gchar *path,
                                     GError **error)
 {
-  GList *preloaded_plugins = NULL;
+  GDir *dir;
+  GError *dir_error = NULL;
+  GrlPlugin *plugin;
+  const gchar *entry;
+  gboolean plugin_loaded = FALSE;
+  gchar *filename;
 
   g_return_val_if_fail (GRL_IS_REGISTRY (registry), FALSE);
+  g_return_val_if_fail (path, FALSE);
 
-  /* Preload plugins */
-  grl_registry_preload_plugins_directory (registry, path, &preloaded_plugins);
-
-  /* Load the plugins */
-  if (!grl_registry_load_plugin_list (registry, preloaded_plugins)) {
-    GRL_WARNING ("No plugins loaded from directory '%s'", path);
+  dir = g_dir_open (path, 0, &dir_error);
+  if (!dir) {
+    GRL_WARNING ("Could not open directory '%s': %s",
+                 path,
+                 dir_error->message);
+    g_set_error (error,
+                 GRL_CORE_ERROR,
+                 GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
+                 _("Invalid path %s"), path);
+    g_error_free (dir_error);
+    return FALSE;
   }
-  g_list_free (preloaded_plugins);
 
-  return TRUE;
+  while ((entry = g_dir_read_name (dir)) != NULL) {
+    filename = g_build_filename (path, entry, NULL);
+    if (g_strrstr (filename, "." G_MODULE_SUFFIX) == NULL) {
+      continue;
+    }
+
+    plugin = grl_registry_prepare_plugin (registry, filename, NULL);
+    plugin_loaded |= (plugin != NULL);
+    g_free (filename);
+  }
+  g_dir_close (dir);
+
+  return plugin_loaded;
 }
 
 /**
  * grl_registry_load_all_plugins:
  * @registry: the registry instance
+ * @activate: %TRUE if plugins must be activated after loading
  * @error: error return location or @NULL to ignore
  *
  * Load all the modules available in the default directory path.
@@ -1440,55 +1294,59 @@ grl_registry_load_plugin_directory (GrlRegistry *registry,
  * Since: 0.2.0
  */
 gboolean
-grl_registry_load_all_plugins (GrlRegistry *registry, GError **error)
+grl_registry_load_all_plugins (GrlRegistry *registry,
+                               gboolean activate,
+                               GError **error)
 {
-  GList *all_plugins;
+  GSList *plugin_dir;
   gboolean loaded_one;
 
   g_return_val_if_fail (GRL_IS_REGISTRY (registry), TRUE);
 
   /* Preload all plugins */
   if (!registry->priv->all_plugins_preloaded) {
-    grl_registry_preload_plugins (registry, NULL);
+    for (plugin_dir = registry->priv->plugins_dir;
+         plugin_dir;
+         plugin_dir = g_slist_next (plugin_dir)) {
+      grl_registry_load_plugin_directory (registry,
+                                          plugin_dir->data,
+                                          NULL);
+    }
     registry->priv->all_plugins_preloaded = TRUE;
   }
 
-  /* Now load all plugins */
-  all_plugins = g_hash_table_get_values (registry->priv->plugins);
-  loaded_one = grl_registry_load_plugin_list (registry, all_plugins);
+  if (activate) {
+    loaded_one = grl_registry_activate_all_plugins (registry);
 
-  g_list_free (all_plugins);
+    if (!loaded_one) {
+      g_set_error (error,
+                   GRL_CORE_ERROR,
+                   GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
+                   _("All configured plugin paths are invalid"));
+    }
 
-  if (!loaded_one) {
-    g_set_error (error,
-                 GRL_CORE_ERROR,
-                 GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
-                 _("All configured plugin paths are invalid"));
+    return loaded_one;
+  } else {
+    return TRUE;
   }
-
-  return loaded_one;
 }
 
 /**
- * grl_registry_load_plugin_by_id:
+ * grl_registry_activate_plugin_by_id:
  * @registry: the registry instance
  * @plugin_id: plugin identifier
  * @error: error return location or @NULL to ignore
  *
- * Loads plugin identified by @plugin_id.
- *
- * This requires the XML plugin information file to define a "module" key with
- * the name of the module that provides the plugin or the absolute path of the
- * actual module file.
+ * Activates plugin identified by @plugin_id.
  *
  * Returns: %TRUE if the plugin is loaded correctly
  *
- * Since: 0.2.0
+ * Since: 0.3.0
  **/
 gboolean
-grl_registry_load_plugin_by_id (GrlRegistry *registry,
-                                const gchar *plugin_id,
-                                GError **error)
+grl_registry_activate_plugin_by_id (GrlRegistry *registry,
+                                    const gchar *plugin_id,
+                                    GError **error)
 {
   GrlPlugin *plugin;
   gboolean is_loaded;
@@ -1497,12 +1355,6 @@ grl_registry_load_plugin_by_id (GrlRegistry *registry,
   g_return_val_if_fail (plugin_id, FALSE);
 
 
-  /* Preload all plugins */
-  if (!registry->priv->all_plugins_preloaded) {
-    grl_registry_preload_plugins (registry, NULL);
-    registry->priv->all_plugins_preloaded = FALSE;
-  }
-
   /* Check if plugin is available */
   plugin = g_hash_table_lookup (registry->priv->plugins, plugin_id);
   if (!plugin) {
@@ -1525,8 +1377,8 @@ grl_registry_load_plugin_by_id (GrlRegistry *registry,
     return FALSE;
   }
 
-  /* Load plugin */
-  return grl_registry_load_plugin (registry, grl_plugin_get_filename (plugin), error);
+  /* activate plugin */
+  return activate_plugin (registry, plugin, error);
 }
 
 /**
@@ -1765,17 +1617,29 @@ grl_registry_unload_plugin (GrlRegistry *registry,
  * grl_registry_register_metadata_key:
  * @registry: The plugin registry
  * @param_spec: (transfer full): The definition of the key to register
+ * @bind_key: The key the new key is bind to, or #GRL_METADATA_KEY_INVALID if it is not bound.
  * @error: error return location or @NULL to ignore
  *
- * Registers a metadata key
+ * Registers a new metadata key, creating a relation between the new key and
+ * @bind_key.
  *
+ * Two keys are related when the values of both keys are somehow related.
+ *
+ * One example of a relation would be the one between the URI of a media
+ * resource and its mime-type: they are both tied together and one does not make
+ * sense without the other.
+ *
+ * Relations between keys allow the framework to provide all the data that is
+ * somehow related when any of the related keys are requested.
+
  * Returns: The #GrlKeyID registered.
  *
- * Since: 0.2.0
+ * Since: 0.3.0
  */
 GrlKeyID
 grl_registry_register_metadata_key (GrlRegistry *registry,
                                     GParamSpec *param_spec,
+                                    GrlKeyID bind_key,
                                     GError **error)
 {
   GrlKeyID key;
@@ -1783,6 +1647,7 @@ grl_registry_register_metadata_key (GrlRegistry *registry,
   key = grl_registry_register_metadata_key_full (registry,
                                                  param_spec,
                                                  GRL_METADATA_KEY_INVALID,
+                                                 bind_key,
                                                  error);
 
   if (key != GRL_METADATA_KEY_INVALID) {
@@ -1807,6 +1672,7 @@ GrlKeyID
 grl_registry_register_metadata_key_system (GrlRegistry *registry,
                                            GParamSpec *param_spec,
                                            GrlKeyID key,
+                                           GrlKeyID bind_key,
                                            GError **error)
 {
   GrlKeyID registered_key;
@@ -1814,64 +1680,12 @@ grl_registry_register_metadata_key_system (GrlRegistry *registry,
   registered_key = grl_registry_register_metadata_key_full (registry,
                                                             param_spec,
                                                             key,
+                                                            bind_key,
                                                             error);
 
   return registered_key;
 }
 
-/**
- * grl_registry_register_metadata_key_relation:
- * @registry: the plugin registry
- * @key1: key involved in relationship
- * @key2: key involved in relationship
- *
- * Creates a relation between @key1 and @key2, meaning that the values of both
- * keys are somehow related.
- *
- * One example of a relation would be the one between the URI of a media
- * resource and its mime-type: they are both tied together and one does not make
- * sense without the other.
- *
- * Relations between keys allow the framework to provide all the data that is
- * somehow related when any of the related keys are requested.
- *
- * Since: 0.2.0
- */
-void
-grl_registry_register_metadata_key_relation (GrlRegistry *registry,
-                                             GrlKeyID key1,
-                                             GrlKeyID key2)
-{
-  GList *key1_partners, *key1_peer;
-  GList *key2_partners;
-
-  g_return_if_fail (GRL_IS_REGISTRY (registry));
-  g_return_if_fail (key1);
-  g_return_if_fail (key2);
-
-  if (key1 == key2) {
-    return;
-  }
-
-  /* Search for keys related with each key */
-  key1_partners = g_hash_table_lookup (registry->priv->related_keys, GRLKEYID_TO_POINTER (key1));
-  key2_partners = g_hash_table_lookup (registry->priv->related_keys, GRLKEYID_TO_POINTER (key2));
-
-  /* Check if they are already related */
-  if (!key1_partners || !key2_partners || key1_partners == key2_partners) {
-    return;
-  }
-
-  /* Merge both relations [related(key1), related(key2)] */
-  key1_partners = g_list_concat(key1_partners, key2_partners);
-
-  for (key1_peer = key1_partners;
-       key1_peer;
-       key1_peer = g_list_next (key1_peer)) {
-    g_hash_table_insert (registry->priv->related_keys, key1_peer->data, key1_partners);
-  }
-}
-
 /**
  * grl_registry_lookup_metadata_key:
  * @registry: the registry instance
