@@ -450,8 +450,8 @@ run_browse (gchar **browse_params)
   }
 
   get_source_and_media (browse_params[0], &source, &media);
-  if (media && !GRL_IS_MEDIA_BOX (media)) {
-    g_print ("%s is not a media box\n", browse_params[0]);
+  if (media && !grl_media_is_container (media)) {
+    g_print ("%s is not a media container\n", browse_params[0]);
     return quit (FALSE);
   }
 
@@ -771,7 +771,7 @@ run_media_from_uri (gchar **uri_params)
   }
 
   options = grl_operation_options_new (NULL);
-  grl_operation_options_set_flags (options, get_flags ());
+  grl_operation_options_set_resolution_flags (options, get_flags ());
 
   print_titles (print_keys);
 
@@ -819,8 +819,8 @@ main (int argc, char *argv[])
   g_option_context_add_main_entries (context, entries, NULL);
   g_option_context_add_group (context, grl_init_get_option_group ());
   g_option_context_set_summary (context,
-                                "\tbrowse <source>|<media box>\n"
-                                "\tmay_resolve <key> <source>|<media box> [<source>]\n"
+                                "\tbrowse <source>|<media container>\n"
+                                "\tmay_resolve <key> <source>|<media container> [<source>]\n"
                                 "\tquery <expression> <source>\n"
                                 "\tresolve <source>|<media> [<source>]\n"
                                 "\tsearch <term> <source>\n"
@@ -858,7 +858,7 @@ main (int argc, char *argv[])
 
   mainloop = g_main_loop_new (NULL, FALSE);
 
-  grl_registry_load_all_plugins (registry, NULL);
+  grl_registry_load_all_plugins (registry, TRUE, NULL);
 
   g_timeout_add_seconds ((guint) delay, run, NULL);
 
