@@ -55,7 +55,7 @@ GRL_LOG_DOMAIN_STATIC(test_ui_log_domain);
 
 /* ----- Youtube Config tokens ---- */
 
-#define YOUTUBE_KEY   "AI39si4EfscPllSfUy1IwexMf__kntTL_G5dfSr2iUEVN45RHGq92Aq0lX25OlnOkG6KTN-4soVAkAf67fWYXuHfVADZYr7S1A"
+#define YOUTUBE_KEY   "AIzaSyDLRGH1fK0-hIlkuVOgi96FLeskI_BDj2k"
 
 /* ----- Vimeo Config tokens ---- */
 
@@ -231,19 +231,19 @@ static void content_changed_cb (GrlSource *source,
 static GtkActionEntry entries[] = {
   { "FileMenuAction", NULL, "_File" },
 #ifdef HAVE_OAUTH
-  { "AuthorizeFlickrAction", GTK_STOCK_CONNECT, "_Authorize Flickr", NULL,
+  { "AuthorizeFlickrAction", NULL, "_Authorize Flickr", NULL,
     "AuthorizeFlickr", G_CALLBACK (authorize_flickr_cb) },
 #endif
-  { "ShutdownPluginsAction", GTK_STOCK_REFRESH, "_Shutdown Plugins", NULL,
+  { "ShutdownPluginsAction", NULL, "_Shutdown Plugins", NULL,
     "ShutdownPlugins", G_CALLBACK (shutdown_plugins_cb) },
-  { "LoadAllPluginsAction", GTK_STOCK_REFRESH, "_Load All Plugins", NULL,
+  { "LoadAllPluginsAction", NULL, "_Load All Plugins", NULL,
     "LoadAllPlugins", G_CALLBACK (load_all_plugins_cb) },
-  { "QuitAction", GTK_STOCK_QUIT, "_Quit", "<control>Q",
+  { "QuitAction", NULL, "_Quit", "<control>Q",
     "Quit", G_CALLBACK (quit_cb) }
 };
 
 static GtkToggleActionEntry toggle_entries[] = {
-  { "ChangesNotificationAction", GTK_STOCK_FIND, "_Changes notification", NULL,
+  { "ChangesNotificationAction", NULL, "_Changes notification", NULL,
     "ChangesNotification", G_CALLBACK (changes_notification_cb), FALSE }
 };
 
@@ -341,13 +341,13 @@ create_query_combo_model (void)
 static GIcon *
 get_icon_for_media (GrlMedia *media)
 {
-  if (GRL_IS_MEDIA_BOX (media)) {
+  if (grl_media_is_container (media)) {
     return g_themed_icon_new ("folder");
-  } else if (GRL_IS_MEDIA_VIDEO (media)) {
+  } else if (grl_media_is_video (media)) {
     return g_themed_icon_new ("gnome-mime-video");
-  } else if (GRL_IS_MEDIA_AUDIO (media)) {
+  } else if (grl_media_is_audio (media)) {
     return g_themed_icon_new ("gnome-mime-audio");
-  } else if (GRL_IS_MEDIA_IMAGE (media)) {
+  } else if (grl_media_is_image (media)) {
     return g_themed_icon_new ("gnome-mime-image");
   } else {
     return g_themed_icon_new ("text-x-generic");
@@ -616,9 +616,9 @@ resolve_cb (GrlSource *source,
        when the treeview is cleared */
 
     /* Set/unset show button */
-    if ((GRL_IS_MEDIA_AUDIO (media) ||
-         GRL_IS_MEDIA_VIDEO (media) ||
-         GRL_IS_MEDIA_IMAGE (media)) &&
+    if ((grl_media_is_audio (media) ||
+         grl_media_is_video (media) ||
+         grl_media_is_image (media)) &&
         (ui_state->last_url = grl_media_get_url (media))) {
       gtk_widget_set_sensitive (view->show_btn, TRUE);
     } else {
@@ -683,9 +683,9 @@ browse_search_query_cb (GrlSource *source,
   if (media) {
     icon = get_icon_for_media (media);
     name = grl_media_get_title (media);
-    if (GRL_IS_MEDIA_BOX (media)) {
+    if (grl_media_is_container (media)) {
       gint childcount =
-        grl_media_box_get_childcount (GRL_MEDIA_BOX (media));
+        grl_media_get_childcount (media);
       type = OBJECT_TYPE_CONTAINER;
       if (childcount != GRL_METADATA_KEY_CHILDCOUNT_UNKNOWN) {
 	name = g_strdup_printf ("%s (%d)", name, childcount);
@@ -770,9 +770,11 @@ browse_search_query_cb (GrlSource *source,
 	    g_object_unref (options);
 	    goto operation_finished;
 	    break;
+	  default:
+	    g_assert_not_reached ();
 	}
 	g_object_unref (options);
-   g_object_unref (supported_options);
+	g_object_unref (supported_options);
 	operation_started (source, next_op_id, FALSE);
       } else {
 	/* We browsed all requested elements  */
@@ -890,21 +892,21 @@ add_source_metadata (GtkTreeModel *model,
 }
 
 static char *
-media_type_to_str (GrlMediaType type)
+supported_media_to_str (GrlMediaType type)
 {
   GString *s;
 
-  if (type == GRL_MEDIA_TYPE_NONE)
+  if (type == GRL_SUPPORTED_MEDIA_NONE)
     return g_strdup ("None");
-  if (type == GRL_MEDIA_TYPE_ALL)
+  if (type == GRL_SUPPORTED_MEDIA_ALL)
     return g_strdup ("All");
 
   s = g_string_new (NULL);
-  if (GRL_MEDIA_TYPE_AUDIO & type)
+  if (GRL_SUPPORTED_MEDIA_AUDIO & type)
     g_string_append (s, "audio, ");
-  if (GRL_MEDIA_TYPE_VIDEO & type)
+  if (GRL_SUPPORTED_MEDIA_VIDEO & type)
     g_string_append (s, "video, ");
-  if (GRL_MEDIA_TYPE_IMAGE & type)
+  if (GRL_SUPPORTED_MEDIA_IMAGE & type)
     g_string_append (s, "image, ");
 
   g_string_truncate (s, s->len - 2);
@@ -953,7 +955,7 @@ populate_source_metadata (GrlSource *source)
     char *str;
     guint auto_split_threshold;
     int rank;
-    GrlMediaType supported_media;
+    GrlSupportedMedia supported_media;
     GIcon *icon;
     char **tags;
 
@@ -979,7 +981,7 @@ populate_source_metadata (GrlSource *source)
     add_source_metadata (view->metadata_model, "rank", str);
     g_free (str);
 
-    str = media_type_to_str (supported_media);
+    str = supported_media_to_str (supported_media);
     add_source_metadata (view->metadata_model, "supported-media", str);
     g_free (str);
 
@@ -1046,7 +1048,7 @@ browser_row_selected_cb (GtkTreeView *tree_view,
       (grl_source_supported_operations (GRL_SOURCE (source)) &
        GRL_OP_STORE)) {
     gtk_widget_set_sensitive (view->store_btn, TRUE);
-  } else if (content && GRL_IS_MEDIA_BOX (content) &&
+  } else if (content && grl_media_is_container (content) &&
 	     grl_source_supported_operations (GRL_SOURCE (source)) &
 	     GRL_OP_STORE_PARENT) {
     gtk_widget_set_sensitive (view->store_btn, TRUE);
@@ -1077,7 +1079,7 @@ show_btn_clicked_cb (GtkButton *btn, gpointer user_data)
   if (ui_state->last_url) {
     GRL_DEBUG ("playing: %s", ui_state->last_url);
     uri_list = g_list_append (uri_list, (gpointer) ui_state->last_url);
-    if (GRL_IS_MEDIA_IMAGE (ui_state->cur_md_media)) {
+    if (grl_media_is_image (ui_state->cur_md_media)) {
       app = launchers->eog;
     } else {
       /* Content from apple-trailers should be opened with mplayer, as they
@@ -1167,8 +1169,8 @@ store_btn_clicked_cb (GtkButton *btn, gpointer user_data)
 				 GTK_WINDOW (view->window),
 				 GTK_DIALOG_MODAL |
 				 GTK_DIALOG_DESTROY_WITH_PARENT,
-				 GTK_STOCK_OK, GTK_RESPONSE_OK,
-				 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				 "Store", GTK_RESPONSE_OK,
+				 "Cancel", GTK_RESPONSE_CANCEL,
 				 NULL);
   GtkWidget *ca = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
   GtkWidget *box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -1197,7 +1199,7 @@ store_btn_clicked_cb (GtkButton *btn, gpointer user_data)
     GrlMedia *media;
     const gchar *url = gtk_entry_get_text (GTK_ENTRY (e2));
     if (!url || !url[0]) {
-      media = grl_media_box_new ();
+      media = grl_media_container_new ();
     } else {
       media = grl_media_new ();
       grl_media_set_url (media, url);
@@ -1205,7 +1207,7 @@ store_btn_clicked_cb (GtkButton *btn, gpointer user_data)
     grl_media_set_title (media, gtk_entry_get_text (GTK_ENTRY (e1)));
     grl_media_set_description (media,
                                     gtk_entry_get_text (GTK_ENTRY (e3)));
-    grl_source_store (source, GRL_MEDIA_BOX (container),
+    grl_source_store (source, container,
                       media, GRL_WRITE_FULL, store_cb, NULL);
   }
 
@@ -1649,9 +1651,9 @@ authorize_flickr (void)
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), label, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), input, TRUE, TRUE, 0);
 
-  ok_button = gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_OK, GTK_RESPONSE_OK);
+  ok_button = gtk_dialog_add_button (GTK_DIALOG (dialog), "Authorize", GTK_RESPONSE_OK);
   gtk_widget_set_sensitive (ok_button, FALSE);
-  gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+  gtk_dialog_add_button (GTK_DIALOG (dialog), "Cancel", GTK_RESPONSE_CANCEL);
 
   g_signal_connect (G_OBJECT (label),
                     "activate-link",
@@ -1964,16 +1966,16 @@ ui_setup (void)
   box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   view->back_btn = gtk_button_new ();
   gtk_button_set_image (GTK_BUTTON (view->back_btn),
-			gtk_image_new_from_stock (GTK_STOCK_GO_BACK,
-						  GTK_ICON_SIZE_BUTTON));
+			gtk_image_new_from_icon_name ("gtk-go-back",
+						      GTK_ICON_SIZE_BUTTON));
   view->store_btn = gtk_button_new ();
   gtk_button_set_image (GTK_BUTTON (view->store_btn),
-			gtk_image_new_from_stock (GTK_STOCK_ADD,
-						  GTK_ICON_SIZE_BUTTON));
+			gtk_image_new_from_icon_name ("list-add",
+						      GTK_ICON_SIZE_BUTTON));
   view->remove_btn = gtk_button_new ();
   gtk_button_set_image (GTK_BUTTON (view->remove_btn),
-			gtk_image_new_from_stock (GTK_STOCK_REMOVE,
-						  GTK_ICON_SIZE_BUTTON));
+			gtk_image_new_from_icon_name ("list-remove",
+						      GTK_ICON_SIZE_BUTTON));
 
   gtk_container_add_with_properties (GTK_CONTAINER (box),
 				     view->back_btn,
@@ -2205,7 +2207,7 @@ content_changed_cb (GrlSource *source,
   for (i = 0; i < changed_medias->len; i++) {
     media = g_ptr_array_index (changed_medias, i);
     media_id = grl_media_get_id (media);
-    if (GRL_IS_MEDIA_BOX (media)) {
+    if (grl_media_is_container (media)) {
       message =
         g_strdup_printf ("%s: container '%s' has %s%s",
                          grl_source_get_name (source),
@@ -2314,7 +2316,7 @@ load_plugins (void)
 		    G_CALLBACK (source_removed_cb), NULL);
   g_signal_connect (registry, "metadata-key-added",
                     G_CALLBACK (metadata_key_added_cb), NULL);
-  if (!grl_registry_load_all_plugins (registry, NULL)) {
+  if (!grl_registry_load_all_plugins (registry, TRUE, NULL)) {
     g_error ("Failed to load plugins.");
   }
 }
@@ -2365,7 +2367,7 @@ load_all_plugins ()
 
   registry = grl_registry_get_default ();
 
-  grl_registry_load_all_plugins (registry, NULL);
+  grl_registry_load_all_plugins (registry, TRUE, NULL);
 }
 
 static void
